==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/GitHub.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.760Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GitHub")
public class GitHub extends io.github.cdklabs.projen.Component {

    protected GitHub(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GitHub(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public GitHub(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GitHubOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public GitHub(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.Dependabot addDependabot(final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.DependabotOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addDependabot", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Dependabot.class), new Object[] { options });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.Dependabot addDependabot() {
        return software.amazon.jsii.Kernel.call(this, "addDependabot", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Dependabot.class));
    }

    /**
     * @param content This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.PullRequestTemplate addPullRequestTemplate(final @org.jetbrains.annotations.NotNull java.lang.String... content) {
        return software.amazon.jsii.Kernel.call(this, "addPullRequestTemplate", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.PullRequestTemplate.class), java.util.Arrays.<Object>stream(content).toArray(Object[]::new));
    }

    /**
     * (experimental) Adds a workflow to the project.
     * <p>
     * @return a GithubWorkflow instance
     * @param name Name of the workflow. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GithubWorkflow addWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "addWorkflow", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Finds a GitHub workflow by name.
     * <p>
     * Returns <code>undefined</code> if the workflow cannot be found.
     * <p>
     * @param name The name of the GitHub workflow. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GithubWorkflow tryFindWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFindWorkflow", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) All workflows.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.github.GithubWorkflow> getWorkflows() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class))));
    }

    /**
     * (experimental) Are workflows enabled?
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getWorkflowsEnabled() {
        return software.amazon.jsii.Kernel.get(this, "workflowsEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) The `Mergify` configured on this repository.
     * <p>
     * This is <code>undefined</code> if Mergify
     * was not enabled when creating the repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.Mergify getMergify() {
        return software.amazon.jsii.Kernel.get(this, "mergify", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Mergify.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.GitHub}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.GitHub> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.github.GitHubOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) Whether mergify should be enabled on this repository or not.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param mergify Whether mergify should be enabled on this repository or not. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergify(final java.lang.Boolean mergify) {
            this.options().mergify(mergify);
            return this;
        }

        /**
         * (experimental) Options for Mergify.
         * <p>
         * Default: - default options
         * <p>
         * @return {@code this}
         * @param mergifyOptions Options for Mergify. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergifyOptions(final io.github.cdklabs.projen.github.MergifyOptions mergifyOptions) {
            this.options().mergifyOptions(mergifyOptions);
            return this;
        }

        /**
         * (experimental) Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param pullRequestLint Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLint(final java.lang.Boolean pullRequestLint) {
            this.options().pullRequestLint(pullRequestLint);
            return this;
        }

        /**
         * (experimental) Options for configuring a pull request linter.
         * <p>
         * Default: - see defaults in `PullRequestLintOptions`
         * <p>
         * @return {@code this}
         * @param pullRequestLintOptions Options for configuring a pull request linter. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLintOptions(final io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions) {
            this.options().pullRequestLintOptions(pullRequestLintOptions);
            return this;
        }

        /**
         * (experimental) Enables GitHub workflows.
         * <p>
         * If this is set to <code>false</code>, workflows will not be created.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param workflows Enables GitHub workflows. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflows(final java.lang.Boolean workflows) {
            this.options().workflows(workflows);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.github.GitHub}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.GitHub build() {
            return new io.github.cdklabs.projen.github.GitHub(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.GitHubOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.GitHubOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/GitHub.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.418Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GitHub")
public class GitHub extends io.github.cdklabs.projen.Component {

    protected GitHub(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GitHub(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public GitHub(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GitHubOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public GitHub(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Returns the <code>GitHub</code> component of a project or <code>undefined</code> if the project does not have a GitHub component.
     * <p>
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GitHub of(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.github.GitHub.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GitHub.class), new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.Dependabot addDependabot(final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.DependabotOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addDependabot", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Dependabot.class), new Object[] { options });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.Dependabot addDependabot() {
        return software.amazon.jsii.Kernel.call(this, "addDependabot", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Dependabot.class));
    }

    /**
     * @param content This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.PullRequestTemplate addPullRequestTemplate(final @org.jetbrains.annotations.NotNull java.lang.String... content) {
        return software.amazon.jsii.Kernel.call(this, "addPullRequestTemplate", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.PullRequestTemplate.class), java.util.Arrays.<Object>stream(content).toArray(Object[]::new));
    }

    /**
     * (experimental) Adds a workflow to the project.
     * <p>
     * @return a GithubWorkflow instance
     * @param name Name of the workflow. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GithubWorkflow addWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "addWorkflow", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Finds a GitHub workflow by name.
     * <p>
     * Returns <code>undefined</code> if the workflow cannot be found.
     * <p>
     * @param name The name of the GitHub workflow. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GithubWorkflow tryFindWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFindWorkflow", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHubActionsProvider getActions() {
        return software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GitHubActionsProvider.class));
    }

    /**
     * (experimental) Whether downloading from LFS is enabled for this GitHub project.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getDownloadLfs() {
        return software.amazon.jsii.Kernel.get(this, "downloadLfs", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) GitHub API authentication method used by projen workflows.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GithubCredentials getProjenCredentials() {
        return software.amazon.jsii.Kernel.get(this, "projenCredentials", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubCredentials.class));
    }

    /**
     * (experimental) All workflows.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.github.GithubWorkflow> getWorkflows() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class))));
    }

    /**
     * (experimental) Are workflows enabled?
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getWorkflowsEnabled() {
        return software.amazon.jsii.Kernel.get(this, "workflowsEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) The <code>Mergify</code> configured on this repository.
     * <p>
     * This is <code>undefined</code> if Mergify
     * was not enabled when creating the repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.Mergify getMergify() {
        return software.amazon.jsii.Kernel.get(this, "mergify", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.Mergify.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.GitHub}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.GitHub> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.github.GitHubOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) Download files in LFS in workflows.
         * <p>
         * Default: true if the associated project has `lfsPatterns`, `false` otherwise
         * <p>
         * @return {@code this}
         * @param downloadLfs Download files in LFS in workflows. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder downloadLfs(final java.lang.Boolean downloadLfs) {
            this.options().downloadLfs(downloadLfs);
            return this;
        }

        /**
         * (experimental) Whether mergify should be enabled on this repository or not.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param mergify Whether mergify should be enabled on this repository or not. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergify(final java.lang.Boolean mergify) {
            this.options().mergify(mergify);
            return this;
        }

        /**
         * (experimental) Options for Mergify.
         * <p>
         * Default: - default options
         * <p>
         * @return {@code this}
         * @param mergifyOptions Options for Mergify. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergifyOptions(final io.github.cdklabs.projen.github.MergifyOptions mergifyOptions) {
            this.options().mergifyOptions(mergifyOptions);
            return this;
        }

        /**
         * (experimental) Choose a method of providing GitHub API access for projen workflows.
         * <p>
         * Default: - use a personal access token named PROJEN_GITHUB_TOKEN
         * <p>
         * @return {@code this}
         * @param projenCredentials Choose a method of providing GitHub API access for projen workflows. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCredentials(final io.github.cdklabs.projen.github.GithubCredentials projenCredentials) {
            this.options().projenCredentials(projenCredentials);
            return this;
        }

        /**
         * (deprecated) The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.
         * <p>
         * This token needs to have the <code>repo</code>, <code>workflows</code>
         * and <code>packages</code> scope.
         * <p>
         * Default: "PROJEN_GITHUB_TOKEN"
         * <p>
         * @return {@code this}
         * @deprecated <ul>
         * <li>use <code>projenCredentials</code></li>
         * </ul>
         * @param projenTokenSecret The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder projenTokenSecret(final java.lang.String projenTokenSecret) {
            this.options().projenTokenSecret(projenTokenSecret);
            return this;
        }

        /**
         * (experimental) Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param pullRequestLint Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLint(final java.lang.Boolean pullRequestLint) {
            this.options().pullRequestLint(pullRequestLint);
            return this;
        }

        /**
         * (experimental) Options for configuring a pull request linter.
         * <p>
         * Default: - see defaults in `PullRequestLintOptions`
         * <p>
         * @return {@code this}
         * @param pullRequestLintOptions Options for configuring a pull request linter. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLintOptions(final io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions) {
            this.options().pullRequestLintOptions(pullRequestLintOptions);
            return this;
        }

        /**
         * (experimental) Enables GitHub workflows.
         * <p>
         * If this is set to <code>false</code>, workflows will not be created.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param workflows Enables GitHub workflows. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflows(final java.lang.Boolean workflows) {
            this.options().workflows(workflows);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.github.GitHub}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.GitHub build() {
            return new io.github.cdklabs.projen.github.GitHub(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.GitHubOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.GitHubOptions.Builder();
            }
            return this.options;
        }
    }
}
